==> casper-bridges-1.0.0.tgz: package/casper.js <==
const axios = require("axios");
const qs = require("qs");

const getToken = async (client_id, client_secret, auth_url) => {
  var data = `grant_type=client_credentials&client_id=${client_id}&client_secret=${client_secret}`;

  var config = {
    method: "post",
    url: `${auth_url}`,
    data: data,
  };

  const response = await axios(config);

  const token = response.data.access_token;

  return token;
};

const getTables = async (caspio) => {
  const response = await caspio.get("tables");
  const tables = response.data.Result;
  return tables;
};

const getRecords = async (caspio, tableName, queries) => {
  let parameters = "?";
  let response;

  if (queries.length > 0) {
    for (p = 0; p < queries.length; p++) {
      if (p === queries.length - 1) {
        parameters = parameters.concat(`${qs.stringify(queries[p])}`);
      } else {
        parameters = parameters.concat(`${qs.stringify(queries[p])}&`);
      }
    }
    response = await caspio.get(`tables/${tableName}/records${parameters}`);
    const records = response.data;
    return records;
  } else {
    response = await caspio.get(`tables/${tableName}/records`);
    const records = response.data;
    return records;
  }
};

async function main() {
  const token = await getToken();

  let queries;
  let records;

  //console.log(token);

  const caspio = axios.create({
    baseURL: "https://c1acl451.caspio.com/rest/v2/",
    headers: {
      Authorization: `Bearer ${token}`,
      "Content-Type": "application/json",
      Accept: "application/json",
    },
  });

  const tables = await getTables(caspio);

  queries = [{ "q.where": "candidateName = 'Test Test'" }];

  records = await getRecords(caspio, "Hybrid_Table", queries);

  console.log(records);
}

main();

==> casper-bridges-1.0.2.tgz: package/casper.js <==
const qs = require("qs");

const getToken = async (client_id, client_secret, auth_url) => {
  // REQ AXIOS
  const axios = require("axios");

  const data = `grant_type=client_credentials&client_id=${client_id}&client_secret=${client_secret}`;

  const config = {
    method: "post",
    url: `${auth_url}`,
    data: data,
  };

  const response = await axios(config);

  const token = response.data.access_token;

  return token;
};

const getTables = async (caspio) => {
  const response = await caspio.get("tables");
  const tables = response.data.Result;
  return tables;
};

const getRecords = async (caspio, tableName, queries) => {
  let parameters = "?";
  let response;

  if (queries.length > 0) {
    for (p = 0; p < queries.length; p++) {
      if (p === queries.length - 1) {
        parameters = parameters.concat(`${qs.stringify(queries[p])}`);
      } else {
        parameters = parameters.concat(`${qs.stringify(queries[p])}&`);
      }
    }
    response = await caspio.get(`tables/${tableName}/records${parameters}`);
    const records = response.data;
    return records;
  } else {
    response = await caspio.get(`tables/${tableName}/records`);
    const records = response.data;
    return records;
  }
};

/*async function main() {
  const token = await getToken();

  let queries;
  let records;

  //console.log(token);

  const caspio = axios.create({
    baseURL: "https://c1acl451.caspio.com/rest/v2/",
    headers: {
      Authorization: `Bearer ${token}`,
      "Content-Type": "application/json",
      Accept: "application/json",
    },
  });

  const tables = await getTables(caspio);

  queries = [{ "q.where": "candidateName = 'Test Test'" }];

  records = await getRecords(caspio, "Hybrid_Table", queries);

  console.log(records);
}

main();*/

export default { getToken, getTables };
